package backstage_model

import "github.com/gogf/gf/os/gtime"

// BilibiliFind  所有分页查询接收信息类型
type BilibiliFind struct {
	IndexPage int `v:"required#页码不能为空"`
	PageSize  int `v:"required#每页展示行数不能为空"`
	Bilibili  *RequestBilibiliFind
}

// RequestBilibiliFind 查询请求参数
type RequestBilibiliFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID
	PlatformId        string   `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string   `orm:"platform_account_id"        json:"platformAccountId"` // 在平台上的账号（自己本地库）
	PlatformNickname  string   `orm:"platform_nickname"          json:"platformNickname"`  // 在平台上的昵称
	SubmitDate        []string `orm:"submit_date"                json:"submitDate"`        // 提交时间
	FansCount         []string `orm:"fans_count"                 json:"fansCount"`         // 粉丝数
	GotLikeCount      int64    `orm:"got_like_count"             json:"gotLikeCount"`      // (点)赞(收)藏数
	HomePageUrl       string   `orm:"home_page_url"              json:"homePageUrl"`       // 主页链接
	SkilledAt         []string `orm:"skilled_at"                 json:"skilledAt"`         // 擅长领域(info_tallent_skilled_area表中的id的数组)
	VisitStoreRegion  string   `orm:"visit_store_region"  json:"visitStoreRegion"`         // 探店区域，取region_info表中的self_code
	AddedStatus       int      `orm:"added_status"               json:"addedStatus"`       // 上架状态
	TalentId          string   `orm:"talent_id,unique"           json:"talentId"`          // 达人账号id(talent_info表id值)
}

// ResponseBilibiliFind 查询请求参数
type ResponseBilibiliFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID，1是小红书，2是抖音
	PlatformId        string      `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string      `orm:"platform_account_id"        json:"platformAccountId"` // 在平台上的账号（平台本身ID）
	PlatformNickname  string      `orm:"platform_nickname"          json:"platformNickname"`  // 在平台上的昵称
	SubmitDate        *gtime.Time `orm:"submit_date"                json:"submitDate"`        // 提交时间
	FansCount         string      `orm:"fans_count"                 json:"fansCount"`         // 粉丝数
	GotLikeCount      int64       `orm:"got_like_count"             json:"gotLikeCount"`      // (点)赞(收)藏数
	HomePageUrl       string      `orm:"home_page_url"              json:"homePageUrl"`       // 主页链接
	SkilledAt         string      `orm:"skilled_at"                 json:"skilledAt"`         // 擅长领域(info_tallent_skilled_area表中的id的数组)
	VisitStoreRegion  int         `orm:"visit_store_region"  json:"visitStoreRegion"`         // 探店区域，取region_info表中的self_code
	TalentId          int         `orm:"talent_id,unique"           json:"talentId"`          // 达人账号id(talent_info表id值)
}

// RemoveAccountBilibili 下架状态操作接收参数
type RemoveAccountBilibili struct {
	PlatformAccountId string `v:"required#平台ID不能为空"`
	Message           string
	Status            string
}

// ResponsePlatformBilibiliAccountInfo 单个查询返回的信息参数
type ResponsePlatformBilibiliAccountInfo struct {
	BilibiliId           int         `orm:"bilibili_id,primary"    json:"bilibiliId"`           //
	PlatformId           int         `orm:"platform_id"            json:"platformId"`           // 平台id，与third_platform_info中的id相同
	PlatformAccountId    string      `orm:"platform_account_id"    json:"platformAccountId"`    // 在平台上的账号
	PlatformNickname     string      `orm:"platform_nickname"      json:"platformNickname"`     // 在平台上的昵称
	HomePageUrl          string      `orm:"home_page_url"          json:"homePageUrl"`          // 主页链接
	FansCount            int64       `orm:"fans_count"             json:"fansCount"`            // 粉丝数
	GotLikeCount         int64       `orm:"got_like_count"         json:"gotLikeCount"`         // 点赞数
	SkilledAt            string      `orm:"skilled_at"             json:"skilledAt"`            // 擅长领域(info_tallent_skilled_area表中的id的数组)
	IsAppearInVideo      int         `orm:"is_appear_in_video"     json:"isAppearInVideo"`      // 是否出镜
	HomePageCaptureUrl   string      `orm:"home_page_capture_url"  json:"homePageCaptureUrl"`   // 主页截图链接
	AccountFrom          string      `orm:"account_from"           json:"accountFrom"`          // 账号来源(仅B端批量上传的账号需要填写)
	PriceCustomizedVideo int64       `orm:"price_customized_video" json:"priceCustomizedVideo"` // 定制视频报价
	PriceEmbedVideo      int64       `orm:"price_embed_video"      json:"priceEmbedVideo"`      // 植入视频报价
	PriceDynamicsPost    int64       `orm:"price_dynamics_post"    json:"priceDynamicsPost"`    // 动态直发报价
	PriceDynamicsRepost  int64       `orm:"price_dynamics_repost"  json:"priceDynamicsRepost"`  // 动态转发报价
	PriceVideoContribute int64       `orm:"price_video_contribute" json:"priceVideoContribute"` // 视频投稿报价
	PriceLive            int64       `orm:"price_live"             json:"priceLive"`            // 直播报价
	PriceSpecialColumn   int64       `orm:"price_special_column"   json:"priceSpecialColumn"`   // 专栏报价
	ExamineStatus        int         `orm:"examine_status"         json:"examineStatus"`        // 审核状态 1待审核 2审核通过 3审核失败
	SubmitDate           *gtime.Time `orm:"submit_date"            json:"submitDate"`           // 提交时间
	ExamineFailAdminId   int         `orm:"examine_fail_admin_id"  json:"examineFailAdminId"`   // 审核失败操作管理员id(user表中的id)
	ExamineDate          *gtime.Time `orm:"examine_date"           json:"examineDate"`          // 审核日期
	ExamineFailReason    string      `orm:"examine_fail_reason"    json:"examineFailReason"`    // 审核失败原因
	UpdatedAt            *gtime.Time `orm:"updated_at"             json:"updatedAt"`            // 更新时间
	ExamineSucAdminId    int         `orm:"examine_suc_admin_id"   json:"examineSucAdminId"`    // 审核成功操作管理员id(user表中的id)
	TalentId             int         `orm:"talent_id,unique"       json:"talentId"`             // 达人账号id(talent_info表id值)
}
