package backstage_model

import "github.com/gogf/gf/os/gtime"

// DianpingFind  所有分页查询接收信息类型
type DianpingFind struct {
	IndexPage int `v:"required#页码不能为空"`
	PageSize  int `v:"required#每页展示行数不能为空"`
	Dianping  *RequestDianpingFind
}

// RequestDianpingFind 查询请求参数
type RequestDianpingFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID
	PlatformId        string   `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string   `orm:"platform_account_id"        json:"platformAccountId"` // 在平台上的账号（自己本地库）
	PlatformNickname  string   `orm:"platform_nickname"          json:"platformNickname"`  // 在平台上的昵称
	SubmitDate        []string `orm:"submit_date"                json:"submitDate"`        // 提交时间
	FansCount         []string `orm:"fans_count"                 json:"fansCount"`         // 粉丝数
	GotLikeCount      int64    `orm:"got_like_count"             json:"gotLikeCount"`      // (点)赞(收)藏数
	HomePageUrl       string   `orm:"home_page_url"              json:"homePageUrl"`       // 主页链接
	VisitStoreRegion  string   `orm:"visit_store_region"  json:"visitStoreRegion"`         // 探店区域，取region_info表中的self_code
	AddedStatus       int      `orm:"added_status"               json:"addedStatus"`       // 上架状态
	TalentId          string   `orm:"talent_id,unique"           json:"talentId"`          // 达人账号id(talent_info表id值)
}

// ResponseDianpingFind 查询请求参数
type ResponseDianpingFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID，1是小红书，2是抖音
	PlatformId        string      `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string      `orm:"platform_account_id"        json:"platformAccountId"` // 在平台上的账号（平台本身ID）
	PlatformNickname  string      `orm:"platform_nickname"          json:"platformNickname"`  // 在平台上的昵称
	SubmitDate        *gtime.Time `orm:"submit_date"                json:"submitDate"`        // 提交时间
	FansCount         string      `orm:"fans_count"                 json:"fansCount"`         // 粉丝数
	GotLikeCount      int64       `orm:"got_like_count"             json:"gotLikeCount"`      // (点)赞(收)藏数
	HomePageUrl       string      `orm:"home_page_url"              json:"homePageUrl"`       // 主页链接
	VisitStoreRegion  int         `orm:"visit_store_region"  json:"visitStoreRegion"`         // 探店区域，取region_info表中的self_code
	TalentId          int         `orm:"talent_id,unique"           json:"talentId"`          // 达人账号id(talent_info表id值)
}

// RemoveAccountDianping 下架状态操作接收参数
type RemoveAccountDianping struct {
	PlatformAccountId string `v:"required#平台ID不能为空"`
	Message           string
	Status            string
}

// ResponsePlatformDianpingAccountInfo 单个查询返回的信息参数
type ResponsePlatformDianpingAccountInfo struct {
	DianpingId         int         `orm:"dianping_id,primary"   json:"dianpingId"`         //
	PlatformId         int         `orm:"platform_id"           json:"platformId"`         // 平台id，与third_platform_info中的id相同
	PlatformAccountId  string      `orm:"platform_account_id"   json:"platformAccountId"`  // 在平台上的账号
	PlatformNickname   string      `orm:"platform_nickname"     json:"platformNickname"`   // 在平台上的昵称
	HomePageUrl        string      `orm:"home_page_url"         json:"homePageUrl"`        // 主页链接
	FansCount          int64       `orm:"fans_count"            json:"fansCount"`          // 粉丝数
	GotLikeCount       int64       `orm:"got_like_count"        json:"gotLikeCount"`       // 点赞数
	MembershipLevel    int         `orm:"membership_level"      json:"membershipLevel"`    // 会员等级
	IsAppearInVideo    int         `orm:"is_appear_in_video"    json:"isAppearInVideo"`    // 是否出镜
	HomePageCaptureUrl string      `orm:"home_page_capture_url" json:"homePageCaptureUrl"` // 主页截图图片url
	AccountFrom        string      `orm:"account_from"          json:"accountFrom"`        // 账号来源(仅B端批量上传的账号需要填写)
	PriceVisitStore    int64       `orm:"price_visit_store"     json:"priceVisitStore"`    // 探店报价
	ExamineStatus      int         `orm:"examine_status"        json:"examineStatus"`      // 审核状态 1待审核 2审核通过 3审核失败
	SubmitDate         *gtime.Time `orm:"submit_date"           json:"submitDate"`         // 提交时间
	ExamineFailAdminId int         `orm:"examine_fail_admin_id" json:"examineFailAdminId"` // 审核失败操作管理员id(user表中的id)
	ExamineDate        *gtime.Time `orm:"examine_date"             json:"examineDate"`     // 审核日期
	ExamineFailReason  string      `orm:"examine_fail_reason"   json:"examineFailReason"`  // 审核失败原因
	UpdatedAt          *gtime.Time `orm:"updated_at"            json:"updatedAt"`          // 更新时间
	ExamineSucAdminId  int         `orm:"examine_suc_admin_id"  json:"examineSucAdminId"`  // 审核成功操作管理员id(user表中的id)
	TalentId           int         `orm:"talent_id,unique"      json:"talentId"`           // 达人账号id(talent_info表id值)
}
