package backstage_model

import "github.com/gogf/gf/os/gtime"

type ExpertRequest struct {
	Id                int               `orm:"id,primary"          json:"id"`
	TalentWxNickname  string            `orm:"talent_wx_nickname"  json:"talentWxNickname"`  // 达人的微信昵称
	TalentPhoneNumber string            `orm:"talent_phone_number" json:"talentPhoneNumber"` // 电话号码
	TalentGender      int               `orm:"talent_gender"       json:"talentGender"`      // 性别，0未知 1男 2女
	Address           []DeliveryAddress `orm:"address"  json:"address"`                      // 是否存在收获地址
	AliName           string            `orm:"ali_name"       json:"aliName"`                // 支付宝姓名
	AliAccount        string            `orm:"ali_account"       json:"aliAccount"`          // 支付宝姓名
	CreateDate        *gtime.Time       `orm:"create_date"         json:"createDate"`        // 创建时间
	LastLoginDate     *gtime.Time       `orm:"last_login_date"     json:"lastLoginDate"`     // 最后登录时间
	InBlacklist       bool              `orm:"in_blacklist"        json:"inBlacklist"`       // 是否加入黑名单 0否 1是
}

// DeliveryAddress 收获地址
type DeliveryAddress struct {
	AddressId    uint64 `orm:"address_id"    json:"addressId"`    // 收获地址ID
	RegionCode   int    `orm:"region_code"   json:"regionCode"`   // 区域码，取info_region表中的self_code字段值
	DetailAddr   string `orm:"detail_addr"   json:"detailAddr"`   // 详细地址
	PhoneNumber  string `orm:"phone_number"  json:"phoneNumber"`  // 联系电话
	ReceiverName string `orm:"receiver_name" json:"receiverName"` // 收货人名字
	DefaultTag   int    `orm:"default_tag"   json:"defaultTag"`   // 是否默认收货地址
	TalentId     int    `orm:"talent_id"     json:"talentId"`     // 达人id(talent_info表中的id)
}

// TalentDeliveryAddress is the golang structure for table talent_delivery_address.
type TalentDeliveryAddress struct {
	AddressId    uint64 `orm:"address_id,primary" json:"addressId"`    //
	RegionCode   int    `orm:"region_code"        json:"regionCode"`   // 区域码，取info_region表中的self_code字段值
	DetailAddr   string `orm:"detail_addr"        json:"detailAddr"`   // 详细地址
	PhoneNumber  string `orm:"phone_number"       json:"phoneNumber"`  // 联系电话
	ReceiverName string `orm:"receiver_name"      json:"receiverName"` // 收货人名字
	DefaultTag   int    `orm:"default_tag"        json:"defaultTag"`   // 是否默认收货地址
	TalentId     int    `orm:"talent_id"          json:"talentId"`     // 达人id(talent_info表中的id)
}

// ExpertFind  所有分页查询接收信息类型
type ExpertFind struct {
	IndexPage int `v:"required#页码不能为空"`
	PageSize  int `v:"required#每页展示行数不能为空"`
	Expert    ExpertRequest
}

// ChangeBlack 修改黑名单状态
type ChangeBlack struct {
	Id     int `orm:"id,primary"          json:"id"`
	Status string
}
