package backstage_model

import "github.com/gogf/gf/os/gtime"

// KuaishouFind  所有分页查询接收信息类型
type KuaishouFind struct {
	IndexPage int `v:"required#页码不能为空"`
	PageSize  int `v:"required#每页展示行数不能为空"`
	Kuaishou  *RequestKuaishouFind
}

// RequestKuaishouFind 查询请求参数
type RequestKuaishouFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID
	PlatformId        string   `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string   `orm:"platform_account_id"        json:"platformAccountId"`   // 在平台上的账号（自己本地库）
	PlatformNickname  string   `orm:"platform_nickname"          json:"platformNickname"`    // 在平台上的昵称
	SubmitDate        []string `orm:"submit_date"                json:"submitDate"`          // 提交时间
	FansCount         []string `orm:"fans_count"                 json:"fansCount"`           // 粉丝数
	CompositionCount  int64    `orm:"composition_count"             json:"compositionCount"` // 作品数量
	HomePageUrl       string   `orm:"home_page_url"              json:"homePageUrl"`         // 主页链接
	SkilledAt         []string `orm:"skilled_at"                 json:"skilledAt"`           // 擅长领域(info_tallent_skilled_area表中的id的数组)
	VisitStoreRegion  string   `orm:"visit_store_region"  json:"visitStoreRegion"`           // 探店区域，取region_info表中的self_code
	AddedStatus       int      `orm:"added_status"               json:"addedStatus"`         // 上架状态
	TalentId          string   `orm:"talent_id,unique"           json:"talentId"`            // 达人账号id(talent_info表id值)
}

// ResponseKuaishouFind 查询请求参数
type ResponseKuaishouFind struct {
	// 平台id，与third_platform_info中的id相同,小红书的ID，1是小红书，2是抖音
	PlatformId        string      `orm:"platform_id"                json:"platformId"`
	PlatformAccountId string      `orm:"platform_account_id"        json:"platformAccountId"`   // 在平台上的账号（平台本身ID）
	PlatformNickname  string      `orm:"platform_nickname"          json:"platformNickname"`    // 在平台上的昵称
	SubmitDate        *gtime.Time `orm:"submit_date"                json:"submitDate"`          // 提交时间
	FansCount         string      `orm:"fans_count"                 json:"fansCount"`           // 粉丝数
	CompositionCount  int64       `orm:"composition_count"             json:"compositionCount"` // 作品数量
	HomePageUrl       string      `orm:"home_page_url"              json:"homePageUrl"`         // 主页链接
	SkilledAt         string      `orm:"skilled_at"                 json:"skilledAt"`           // 擅长领域(info_tallent_skilled_area表中的id的数组)
	VisitStoreRegion  int         `orm:"visit_store_region"  json:"visitStoreRegion"`           // 探店区域，取region_info表中的self_code
	TalentId          int         `orm:"talent_id,unique"           json:"talentId"`            // 达人账号id(talent_info表id值)
}

// RemoveAccountKuaishou 下架状态操作接收参数
type RemoveAccountKuaishou struct {
	PlatformAccountId string `v:"required#平台ID不能为空"`
	Message           string
	Status            string
}

// ResponsePlatformKuaishouAccountInfo 单个查询返回的信息参数
type ResponsePlatformKuaishouAccountInfo struct {
	KuaishouId          int         `orm:"kuaishou_id,primary"      json:"kuaishouId"`          //
	PlatformId          int         `orm:"platform_id"              json:"platformId"`          // 平台id，与third_platform_info中的id相同
	PlatformAccountId   string      `orm:"platform_account_id"      json:"platformAccountId"`   // 在平台上的账号
	PlatformNickname    string      `orm:"platform_nickname"        json:"platformNickname"`    // 在平台上的昵称
	HomePageUrl         string      `orm:"home_page_url"            json:"homePageUrl"`         // 主页链接
	FansCount           int64       `orm:"fans_count"               json:"fansCount"`           // 粉丝数
	CompositionCount    int64       `orm:"composition_count"        json:"compositionCount"`    // 作品数量
	SkilledAt           string      `orm:"skilled_at"               json:"skilledAt"`           // 擅长领域(info_tallent_skilled_area表中的id的数组)
	IsSupportLive       int         `orm:"is_support_live"          json:"isSupportLive"`       // 是否支持直播
	IsOpenCart          int         `orm:"is_open_cart"             json:"isOpenCart"`          // 是否开通购物车
	IsAppearInVideo     int         `orm:"is_appear_in_video"       json:"isAppearInVideo"`     // 是否出镜
	HomePageCaptureUrl  string      `orm:"home_page_capture_url"    json:"homePageCaptureUrl"`  // 主页截图图片url
	AccountFrom         string      `orm:"account_from"             json:"accountFrom"`         // 账号来源(仅B端批量上传的账号需要填写)
	PriceKuaiOrder      int64       `orm:"price_kuai_order"         json:"priceKuaiOrder"`      // 快接单价格
	PriceNoReport1To20  int64       `orm:"price_no_report_1_to_20"  json:"priceNoReport1To20"`  // 非报备视频1--20秒价格
	PriceNoReport20To60 int64       `orm:"price_no_report_20_to_60" json:"priceNoReport20To60"` // 非报备视频20--60秒价格
	PriceNoReportGt60   int64       `orm:"price_no_report_gt_60"    json:"priceNoReportGt60"`   // 非报备视频60秒以上价格
	PriceLive           int64       `orm:"price_live"               json:"priceLive"`           // 直播价格
	SubmitDate          *gtime.Time `orm:"submit_date"              json:"submitDate"`          // 提交时间
	ExamineFailAdminId  int         `orm:"examine_fail_admin_id"    json:"examineFailAdminId"`  // 审核失败操作管理员id(user表中的id)
	ExamineDate         *gtime.Time `orm:"examine_date"             json:"examineDate"`         // 审核日期
	ExamineFailReason   string      `orm:"examine_fail_reason"      json:"examineFailReason"`   // 审核失败原因
	UpdatedAt           *gtime.Time `orm:"updated_at"               json:"updatedAt"`           // 更新时间
	ExamineSucAdminId   int         `orm:"examine_suc_admin_id"     json:"examineSucAdminId"`   // 审核成功操作管理员id(user表中的id)
	TalentId            int         `orm:"talent_id,unique"         json:"talentId"`            // 达人账号id(talent_info表id值)
}
