package backstage_service

import (
	"github.com/gogf/gf/frame/g"
	"youngmini_server/app/model/backstage_model"
	"youngmini_server/app/utils"
)

var Kuaishou = serviceKuaishou{}

type serviceKuaishou struct{}

// FindAllKuaishou 查询所有
func (s *serviceKuaishou) FindAllKuaishou(kuaishou *backstage_model.KuaishouFind) ([]*backstage_model.ResponseKuaishouFind, int, error) {
	var res []*backstage_model.ResponseKuaishouFind
	number, err := utils.RelyNumber(4)
	if err != nil {
		return nil, 0, err
	}
	g.DB().SetDebug(true)
	err = g.DB().Model("platform_kuaishou_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").
		OmitEmpty().Where("talent_id IN(?)", number).Fields("`platform_id`,`platform_account_id`,`platform_nickname`,`submit_date`,`fans_count`,`composition_count`,`home_page_url`,`skilled_at`,`talent_id`,visit_store_region").
		Page(kuaishou.IndexPage, kuaishou.PageSize).OrderDesc("talent_id").Scan(&res)
	if err != nil {
		return nil, 0, err
	}
	var result []*backstage_model.ResponseKuaishouFind
	err = g.DB().Model("platform_kuaishou_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").OmitEmpty().Where("talent_id IN(?)", number).
		OrderDesc("talent_id").Scan(&result)
	if err != nil {
		return nil, 0, err
	}
	num := len(result)
	return res, num, nil
}

// FindByConditionKuaishou 根据查询条件查询
func (s *serviceKuaishou) FindByConditionKuaishou(kuaishou *backstage_model.KuaishouFind) ([]*backstage_model.ResponseKuaishouFind, int, error) {
	var res []*backstage_model.ResponseKuaishouFind
	if kuaishou.Kuaishou == nil {
		res, num, err := s.FindAllKuaishou(kuaishou)
		if err != nil {
			return nil, 0, err
		}
		return res, num, nil
	}
	number, err := utils.RelyNumber(4)
	if err != nil {
		return nil, 0, err
	}
	g.DB().SetDebug(true)
	// 拼接数据库查询字符串语句
	contact := s.contact(kuaishou.Kuaishou)
	err = g.DB().Model("platform_kuaishou_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").
		OmitEmpty().Where(contact).Where("talent_id IN(?)", number).Fields("`platform_id`,`platform_account_id`,`platform_nickname`,`submit_date`,`fans_count`,`composition_count`,`home_page_url`,`skilled_at`,`talent_id`,visit_store_region").
		Page(kuaishou.IndexPage, kuaishou.PageSize).OrderDesc("talent_id").Scan(&res)
	if err != nil {
		return nil, 0, err
	}
	var result []*backstage_model.ResponseKuaishouFind
	err = g.DB().Model("platform_kuaishou_account_info").LeftJoin("talent_info", "talent_id = talent_info.id").
		OmitEmpty().Where(contact).Where("talent_id IN(?)", number).
		Scan(&result)
	if err != nil {
		return nil, 0, err
	}
	num := len(result)
	return res, num, nil
}

// RemoveAccount 账号下架操作
func (s *serviceKuaishou) RemoveAccount(status *backstage_model.RemoveAccountKuaishou) error {
	g.DB().SetDebug(true)
	_, err := g.DB().Model("platform_kuaishou_account_info").
		Data(g.Map{"examine_status": "3", "examine_fail_reason": status.Message}).
		Where("platform_account_id", status.PlatformAccountId).Update()
	if err != nil {
		return err
	}
	return nil
}

// 拼接数据库数据库where语句字符串
func (s *serviceKuaishou) contact(kuaishou *backstage_model.RequestKuaishouFind) string {
	var res []string
	if kuaishou.PlatformAccountId != "" {
		res = append(res, "platform_account_id="+kuaishou.PlatformAccountId)
	}
	if kuaishou.TalentId != "" {
		res = append(res, "talent_id="+kuaishou.TalentId)
	}
	if len(kuaishou.SubmitDate) != 0 {
		res = append(res, "submit_date>'"+kuaishou.SubmitDate[0]+" 00:00:00' and "+
			"submit_date<'"+kuaishou.SubmitDate[1]+" 23:59:59'")
	}
	if len(kuaishou.FansCount) != 0 {
		res = append(res, "fans_count>="+kuaishou.FansCount[0]+" and fans_count<="+kuaishou.FansCount[1])
	}
	if kuaishou.VisitStoreRegion != "" {
		res = append(res, "visit_store_region="+kuaishou.VisitStoreRegion)
	}
	if len(kuaishou.SkilledAt) != 0 {
		// JSON_CONTAINS包含语句
		var temp string
		for index, value := range kuaishou.SkilledAt {
			if index == 0 {
				temp = "JSON_CONTAINS(skilled_at,'" + value + "')"
			} else {
				temp = " OR JSON_CONTAINS(skilled_at,'" + value + "')"
			}
		}
		res = append(res, "("+temp+")")
	}
	var result string
	for _, value := range res {
		result += " and " + value
	}
	return result
}

// FindAllById 单个查询所有
func (s *serviceKuaishou) FindAllById(kuaishou *backstage_model.RemoveAccountKuaishou) (*backstage_model.ResponsePlatformKuaishouAccountInfo, error) {
	var res *backstage_model.ResponsePlatformKuaishouAccountInfo
	err := g.DB().Model("platform_kuaishou_account_info").Where("talent_id", kuaishou.PlatformAccountId).Scan(&res)
	if err != nil {
		return nil, err
	}
	return res, nil
}
